/************************************************************

Created: Friday, September 27, 1991 10:04:39 AM
 ImageCodec.h
 C Interface to the Macintosh Libraries


 Copyright Apple Computer, Inc. 1991
 All rights reserved

************************************************************/


#ifndef	__IMAGECODEC__
#define	__IMAGECODEC__

#ifndef __QUICKDRAW__
#include <QuickDraw.h>
#endif

#ifndef __QDOFFSCREEN__
#include <QDOffscreen.h>
#endif

#ifndef __TYPES__
#include <Types.h>
#endif

#ifndef __COMPONENTS__
#include "Components.h"
#endif

#ifndef	__IMAGECOMPRESSION__
#include "ImageCompression.h"
#endif	

/*	codec component selectors	*/
/*	codec selectors 0-127 are reserved by Apple */
/*	codec selectors 128-191 are subtype specific */
/*	codec selectors 192-255 are vendor specific */
/*	codec selectors 256-32767 are reserved by Apple */
/*	negative selectors are reserved by the Component Manager */

#define	codecGetCodecInfo					0x00
#define	codecGetCompressionTime				0x01
#define	codecGetMaxCompressionSize			0x02
#define	codecPreCompress					0x03
#define	codecBandCompress					0x04
#define	codecPreDecompress					0x05
#define	codecBandDecompress					0x06
#define	codecCDSequenceBusy					0x07
#define	codecGetCompressedImageSize			0x08
#define	codecGetSimilarity					0x09
#define	codecTrimImage						0x0A





/*	codec capabilities flags	*/

#define	codecCanScale						(1L<<0)
#define	codecCanMask						(1L<<1)
#define	codecCanMatte						(1L<<2)
#define	codecCanTransform					(1L<<3)
#define	codecCanTransferMode				(1L<<4)
#define	codecCanCopyPrev					(1L<<5)
#define	codecCanSpool						(1L<<6)
#define	codecCanClipVertical				(1L<<7)
#define	codecCanClipRectangular				(1L<<8)
#define	codecCanRemapColor					(1L<<9)
#define	codecCanFastDither					(1L<<10)
#define	codecCanSrcExtract					(1L<<11)
#define	codecCanCopyPrevComp				(1L<<12)
#define	codecCanAsync						(1L<<13)
#define	codecCanMakeMask					(1L<<14)
#define codecCanShift						(1L<<15)




/*	codec condition flags	*/


#define	codecConditionFirstBand				(1L<<0)	
#define	codecConditionLastBand				(1L<<1)	
#define	codecConditionCodecChangedMask		(1L<<31)	



#define	codecInfoResourceType				'cdci'			/* codec info resource type */


typedef	struct {
	long	flags;
	short	wantedPixelSize;
	short	extendWidth;
	short	extendHeight;
	short	bandMin;
	short	bandInc;
	short	pad;
	unsigned long	time;
} CodecCapabilities;

typedef	 CodecCapabilities *CodecCapabilitiesPtr;

typedef	struct {	
	ImageSequence 			sequenceID;				/* precompress,bandcompress */
	ImageDescriptionHandle 	imageDescription;		/* precompress,bandcompress */
	Ptr 					data;
	long 					bufferSize;
	long 					frameNumber;
	long 					startLine;
	long 					stopLine;
	long					conditionFlags;
	CodecFlags 				callerFlags;
	CodecCapabilitiesPtr 	capabilities;			/* precompress,bandcompress */
	ProgressProcRecord		progressProcRecord;
	CompletionProcRecord	completionProcRecord;	
	FlushProcRecord 		flushProcRecord;

	PixMap 					srcPixMap;				/* precompress,bandcompress */
	PixMap 					prevPixMap;
	CodecQ 					spatialQuality;
	CodecQ 					temporalQuality;
	Fixed		 			similarity;
	long					reserved[2];
} CodecCompressParams;

typedef CodecCompressParams *CodecCompressParamsPtr;

typedef	struct {	
	ImageSequence 			sequenceID;				/* predecompress,banddecompress */
	ImageDescriptionHandle 	imageDescription;		/* predecompress,banddecompress */
	Ptr 					data;
	long 					bufferSize;
	long 					frameNumber;
	long 					startLine;
	long 					stopLine;
	long					conditionFlags;
	CodecFlags 				callerFlags;
	CodecCapabilitiesPtr 	capabilities;			/* predecompress,banddecompress */
	ProgressProcRecord		progressProcRecord;
	CompletionProcRecord	completionProcRecord;
	DataProcRecord			dataProcRecord;

	CGrafPtr 				port;					/* predecompress,banddecompress */
	PixMap 					dstPixMap;				/* predecompress,banddecompress */
	BitMapPtr 				maskBits;
	PixMapPtr 				mattePixMap;
	Rect 					srcRect;				/* predecompress,banddecompress */
	MatrixRecordPtr			matrix;					/* predecompress,banddecompress */
	CodecQ 					accuracy;				/* predecompress,banddecompress */
	short 					transferMode;			/* predecompress,banddecompress */
	long					reserved[2];
} CodecDecompressParams;
typedef CodecDecompressParams *CodecDecompressParamsPtr;


pascal ComponentResult
CDGetCodecInfo(Handle	storage,CodecInfo *info);

pascal ComponentResult
CDGetCompressionTime(Handle	storage,PixMapHandle src,const Rect *srcRect, short depth,CodecQ *spatialQuality,
	CodecQ *temporalQuality,unsigned long *time);


pascal ComponentResult
CDGetMaxCompressionSize(Handle	storage,PixMapHandle src,const Rect *srcRect, short depth,CodecQ quality,
	long *size);


pascal ComponentResult
CDPreCompress(Handle	storage,CodecCompressParams *params);

pascal ComponentResult
CDBandCompress(Handle	storage,CodecCompressParams *params);

pascal ComponentResult
CDPreDecompress(Handle	storage,CodecDecompressParams *params);

pascal ComponentResult
CDBandDecompress(Handle	storage,CodecDecompressParams *params);

pascal ComponentResult
CDCodecBusy(Handle	storage,ImageSequence seq);


pascal ComponentResult
CDGetCompressedImageSize(Handle	storage,ImageDescriptionHandle desc,Ptr data,long bufferSize, 
	DataProcRecordPtr dataProc,long *dataSize);

pascal ComponentResult
CDGetSimilarity(Handle	storage,PixMapHandle src,const Rect *srcRect,ImageDescriptionHandle desc,Ptr data,
	Fixed *similarity);

pascal ComponentResult
CDTrimImage(Handle	storage,ImageDescriptionHandle desc,Ptr inData,long inBufferSize, DataProcRecordPtr dataProc,
	Ptr outData,long outBufferSize,FlushProcRecordPtr flushProc,Rect *trimRect,ProgressProcRecordPtr progressProc);




#endif	__IMAGECODEC__
